#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 mysql-simple
version:              0.4.9
visibility:           public
id:                   mysql-simple-0.4.9-95dJqdzHRjT5q9aUlC0Z1C
key:                  mysql-simple-0.4.9-95dJqdzHRjT5q9aUlC0Z1C
license:              BSD-3-Clause
copyright:            2011 MailRank, Inc.
maintainer:           Paul Rouse <pyr@doynton.org>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
homepage:             https://github.com/paul-rouse/mysql-simple
synopsis:             A mid-level MySQL client library.
description:
    A mid-level client library for the MySQL database, intended to be
    fast and easy to use.

    /Important licensing note/: This library is BSD-licensed under the
    terms of the MySQL FOSS License Exception
    <http://www.mysql.com/about/legal/licensing/foss-exception/>.

    Since this library links against the GPL-licensed @mysqlclient@
    library, a non-open-source application that uses it /may/ be
    subject to the terms of the GPL.

category:             Database
abi:                  ad007e255a4ce520ee4d44e8b202c697
exposed:              True
exposed-modules:
    Database.MySQL.Simple Database.MySQL.Simple.Param
    Database.MySQL.Simple.QueryParams
    Database.MySQL.Simple.QueryResults Database.MySQL.Simple.Result
    Database.MySQL.Simple.Types

hidden-modules:       Database.MySQL.Internal.Blaze
import-dirs:          /usr/lib/ghc-9.6.6/site-local/mysql-simple-0.4.9
library-dirs:         /usr/lib/ghc-9.6.6/site-local/mysql-simple-0.4.9
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/mysql-simple-0.4.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mysql-simple
hs-libraries:         HSmysql-simple-0.4.9-95dJqdzHRjT5q9aUlC0Z1C
depends:
    attoparsec-0.14.4-Lt8CzeQB1UCKNIPCgGeJTD base-4.18.2.1
    base16-bytestring-1.0.2.0-BOZQoJvp04k6zWThJ612WV
    blaze-builder-0.4.4.1-7DIK9vMysGNGOGHtPzm22s bytestring-0.11.5.3
    containers-0.6.7 mysql-0.2.1-3hUuTZukSoIJB5TYB2NQnM
    old-locale-1.0.0.7-Gunit3UBy5P9OGDVFY5MhC
    pcre-light-0.4.1.3-LJnGRx9YMSlIeQnqxNBHah text-2.0.2 time-1.12.2
    vector-0.13.2.0-Bce9rIW4lAD9r12sFleKX

haddock-interfaces:
    /usr/share/doc/haskell-mysql-simple/html/mysql-simple.haddock

haddock-html:         /usr/share/doc/haskell-mysql-simple/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

